==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/Stacked100SplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSplineSeriesDescriptionMetadata } from "./StackedSplineSeriesDescriptionMetadata";
import { Stacked100SplineSeriesDescription } from "./Stacked100SplineSeriesDescription";
/**
 * @hidden
 */
var Stacked100SplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeriesDescriptionMetadata, _super);
    function Stacked100SplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100SplineSeriesDescriptionMetadata.b = function (a) {
        if (Stacked100SplineSeriesDescriptionMetadata.a == null) {
            Stacked100SplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Stacked100SplineSeriesDescriptionMetadata.c(Stacked100SplineSeriesDescriptionMetadata.a);
        }
        if (a.g(Stacked100SplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(Stacked100SplineSeriesDescriptionMetadata.a);
    };
    Stacked100SplineSeriesDescriptionMetadata.c = function (a) {
        StackedSplineSeriesDescriptionMetadata.c(a);
    };
    Stacked100SplineSeriesDescriptionMetadata.d = function (a) {
        Stacked100SplineSeriesDescriptionMetadata.b(a);
        a.u("Stacked100SplineSeries", function () { return new Stacked100SplineSeriesDescription(); });
        a.t("Stacked100SplineSeries", Stacked100SplineSeriesDescriptionMetadata.a);
    };
    Stacked100SplineSeriesDescriptionMetadata.$t = markType(Stacked100SplineSeriesDescriptionMetadata, 'Stacked100SplineSeriesDescriptionMetadata');
    Stacked100SplineSeriesDescriptionMetadata.a = null;
    return Stacked100SplineSeriesDescriptionMetadata;
}(Base));
export { Stacked100SplineSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/Stacked100SplineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSplineSeriesDescriptionMetadata } from "./StackedSplineSeriesDescriptionMetadata";
import { Stacked100SplineSeriesDescription } from "./Stacked100SplineSeriesDescription";
/**
 * @hidden
 */
var Stacked100SplineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineSeriesDescriptionMetadata, _super);
    function Stacked100SplineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100SplineSeriesDescriptionMetadata.b = function (a) {
        if (Stacked100SplineSeriesDescriptionMetadata.a == null) {
            Stacked100SplineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Stacked100SplineSeriesDescriptionMetadata.c(Stacked100SplineSeriesDescriptionMetadata.a);
        }
        if (a.j(Stacked100SplineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(Stacked100SplineSeriesDescriptionMetadata.a);
    };
    Stacked100SplineSeriesDescriptionMetadata.c = function (a) {
        StackedSplineSeriesDescriptionMetadata.c(a);
    };
    Stacked100SplineSeriesDescriptionMetadata.d = function (a) {
        Stacked100SplineSeriesDescriptionMetadata.b(a);
        a.aa("Stacked100SplineSeries", function () { return new Stacked100SplineSeriesDescription(); });
        a.z("Stacked100SplineSeries", Stacked100SplineSeriesDescriptionMetadata.a);
    };
    Stacked100SplineSeriesDescriptionMetadata.$t = markType(Stacked100SplineSeriesDescriptionMetadata, 'Stacked100SplineSeriesDescriptionMetadata');
    Stacked100SplineSeriesDescriptionMetadata.a = null;
    return Stacked100SplineSeriesDescriptionMetadata;
}(Base));
export { Stacked100SplineSeriesDescriptionMetadata };
